import os
import os.path
import sys
import glob
import platform
import sasktranif
import sasktranif.sasktranif

#------------------------------------------------------------------------------
#           CreateRegistryEntries
#  A one time installation process that configures the local python environment
#  registry. This is typically a YAML based registry. It is intended that this
#  function is invoked as part of the python installation process. It is invoked
#  after pip install sasktranif... The code works well if the user has already
#  installed the Sasktran Core Components on their machine using the .msi file
#  as it copies  relevant "read only" settings from the main registry into the python's
#  yaml registry.
#
#  The code only works properly on Windows with sasktran core components
#  already installed. Linux users currently have to manually edit the python YAML
#  registry file.
#
#------------------------------------------------------------------------------

def CreateRegistryEntries():

   filename = sys.modules["sktran_disco"].__file__                                         # Get the filename of the sasktranif.py file
   dirname  = os.path.dirname(filename)                                                 # Now get the directory of that file    
   if platform.system() == 'Windows':
      dllname = dirname + os.sep + 'isk_disco.dll'
   else:                                          
      dllname = dirname + os.sep + 'libisk_disco.so'

   paramstr = dllname
   sasktranif.sasktranif.SKTRAN_IFCreateRegistryEntriesForDLL(dllname, paramstr)
#              param[0] =  full path name of this DLL.


CreateRegistryEntries()
